@@ -44,11 +44,10 @@ from zipfile import ZipFile
 
 # 3rd party
 import click
-from consolekit.terminal_colours import resolve_color_default
+from consolekit.terminal_colours import Fore, resolve_color_default
 from consolekit.utils import abort
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
-from domdf_python_tools.terminal_colours import Fore
 from domdf_python_tools.typing import PathLike
 from packaging.specifiers import Specifier
 from packaging.version import Version
@@ -56,6 +55,7 @@ from shippinglabel.requirements import ComparableRequirement, combine_requiremen
 
 # this package
 from repo_helper import __version__
+from repo_helper.conda import compile_requirements, validate_requirements
 from repo_helper.configuration import parse_yaml
 from repo_helper.utils import traverse_to_file
 
@@ -395,34 +395,22 @@ class Builder:
 		build_string = f"py_{build_number}"
 		# https://docs.conda.io/projects/conda-build/en/latest/resources/define-metadata.html#build-number-and-string
 
-		extra_requirements = []
-		all_requirements = []
+		extras = []
 
-		for extra, requirements in self.config["extras_require"].items():
-			extra_requirements.extend([ComparableRequirement(r) for r in requirements])
+		for extra in self.config["conda_extras"]:
+			extras.extend(self.config["extras_require"][extra])
 
-		for requirement in sorted(
-				combine_requirements(
-						*read_requirements(self.repo_dir / "requirements.txt")[0],
-						*extra_requirements,
-						),
-				):
-			if requirement.url:
-				continue
-
-			if requirement.extras:
-				requirement.extras = set()
-			if requirement.marker:
-				requirement.marker = None
-
-			all_requirements.append(str(requirement))
+		all_requirements = validate_requirements(
+				compile_requirements(self.repo_dir, extras),
+				self.config["conda_channels"],
+				)
 
 		index = {
 				"name": self.config["repo_name"].lower(),
 				"version": self.config["version"],
 				"build": build_string,
 				"build_number": build_number,
-				"depends": all_requirements,
+				"depends": [str(req) for req in all_requirements],
 				"arch": None,
 				"noarch": "python",
 				"platform": None,
