@@ -35,15 +35,14 @@ __all__ = ["make_recipe"]
 
 @autocomplete_option("-o", "--out-dir", type=click.STRING, default="./conda/", help="The output directory.")
 @cli_command()
-def make_recipe(out_dir) -> int:
+def make_recipe(out_dir: str = "./conda/"):
 	"""
 	Make a Conda ``meta.yaml`` recipe.
 	"""
 
 	# 3rd party
-	from consolekit.terminal_colours import resolve_color_default
+	from consolekit.terminal_colours import Fore, resolve_color_default
 	from domdf_python_tools.paths import PathPlus
-	from domdf_python_tools.terminal_colours import Fore
 
 	# this package
 	from repo_helper import conda
@@ -57,5 +56,3 @@ def make_recipe(out_dir) -> int:
 	conda.make_recipe(repo_dir, recipe_file)
 
 	click.echo(Fore.GREEN(f"Wrote recipe to {recipe_file!s}"), color=resolve_color_default())
-
-	return 0
