@@ -95,7 +95,7 @@ suggest_command = partial(suggest.command, context_settings=CONTEXT_SETTINGS)
 		help="Indicates this project is a library for developers.",
 		)
 @suggest_command()
-def classifiers(add: bool, status: Optional[int], library: Optional[bool]) -> int:
+def classifiers(add: bool, status: Optional[int], library: Optional[bool]):
 	"""
 	Suggest trove classifiers based on repository metadata.
 	"""
@@ -204,8 +204,14 @@ def classifiers(add: bool, status: Optional[int], library: Optional[bool]) -> in
 	# 		filter(remove_invalid_entries, (click.edit(file_content) or file_content).splitlines())
 	# 		)
 
+	if not suggested_classifiers:
+		if sys.stdout.isatty():
+			click.echo("Sorry, I've nothing to suggest 😢")
+
+		sys.exit(1)
+
 	if sys.stdout.isatty():
-		click.echo("Based on what you've told us we think the following classifiers are appropriate:")
+		click.echo("Based on what you've told me I think the following classifiers are appropriate:")
 		for classifier in sorted(suggested_classifiers):
 			click.echo(f" - {classifier}")
 	else:
@@ -242,7 +248,5 @@ def classifiers(add: bool, status: Optional[int], library: Optional[bool]) -> in
 				fp.write("\n")
 				yaml.dump({"classifiers": sorted(suggested_classifiers)}, fp)
 
-	return 0
-
 
 # TODO: flags for interactive options, and clean output when piped
