@@ -42,6 +42,7 @@ __all__ = [
 		"lint_warn_list",
 		"make_pylintrc",
 		"make_lint_roller",
+		"remove_lint_roller",
 		"code_only_warning",
 		]
 
@@ -133,7 +134,6 @@ lint_warn_list.extend((
 		"PT001",  # use @pytest.fixture() over @pytest.fixture (configurable by pytest-fixture-no-parentheses)
 		"PT002",  # configuration for fixture '{name}' specified via positional args, use kwargs
 		"PT003",  # scope='function' is implied in @pytest.fixture()
-		"PT004",  # fixture '{name}' does not return anything, add leading underscore
 		"PT005",  # fixture '{name}' returns a value, remove leading underscore
 		"PT006",  # wrong name(s) type in @pytest.mark.parametrize
 		"PT007",  # wrong values type in @pytest.mark.parametrize
@@ -191,7 +191,6 @@ lint_warn_list.extend((
 
 # flake8-quotes
 lint_warn_list.extend((
-		"Q000",  # Remove bad quotes
 		"Q001",  # Remove bad quotes from multiline string
 		"Q002",  # Remove bad quotes from docstring
 		"Q003",  # Change outer quotes to avoid escaping inner quotes
@@ -293,6 +292,22 @@ def make_pylintrc(repo_path: pathlib.Path, templates: jinja2.Environment) -> Lis
 
 
 @management.register("lint_roller")
+def remove_lint_roller(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
+	"""
+	Remove the old lint_roller.sh script to the desired repo.
+
+	:param repo_path: Path to the repository root.
+	:param templates:
+	"""
+
+	lint_file = PathPlus(repo_path / "lint_roller.sh")
+	if lint_file.is_file():
+		lint_file.unlink()
+
+	return [lint_file.name]
+
+
+# @management.register("lint_roller")
 def make_lint_roller(repo_path: pathlib.Path, templates: jinja2.Environment) -> List[str]:
 	"""
 	Add the lint_roller.sh script to the desired repo.
