@@ -30,15 +30,15 @@ import posixpath
 import re
 from io import StringIO
 from textwrap import indent
-from typing import Iterable, List, MutableMapping, Union
+from typing import Iterable, List, Mapping, MutableMapping, Union
 
 # 3rd party
 import attr
 import jinja2
+import ruamel.yaml
 from apeye.url import URL
 from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
-from ruamel import yaml
 from typing_extensions import Literal, TypedDict
 
 # this package
@@ -150,6 +150,7 @@ pre_commit_hooks = Repo(
 		hooks=[
 				"check-added-large-files",
 				"check-ast",
+				"fix-byte-order-marker",
 				"check-byte-order-marker",
 				"check-case-conflict",
 				"check-executables-have-shebangs",
@@ -160,9 +161,9 @@ pre_commit_hooks = Repo(
 				"check-symlinks",
 				"check-vcs-permalinks",
 				"detect-private-key",
-				"end-of-file-fixer",
 				"trailing-whitespace",
 				"mixed-line-ending",
+				"end-of-file-fixer",
 				]
 		)
 
@@ -224,7 +225,7 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 
 	domdfcoding_hooks = Repo(
 			repo=make_github_url("domdfcoding", "pre-commit-hooks"),
-			rev="v0.1.1",
+			rev="v0.1.4",
 			hooks=[
 					{"id": "requirements-txt-sorter", "args": ["--allow-git"]},
 					{
@@ -244,15 +245,26 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 					}]
 			)
 
+	yapf_isort_excludes = fr"^({'|'.join([*templates.globals['yapf_exclude'], *non_source_files])})\.py$"
+
 	yapf_isort = Repo(
 			repo=make_github_url("domdfcoding", "yapf-isort"),
-			rev="v0.4.4",
-			hooks=[{"id": "yapf-isort", "exclude": fr"^({'|'.join(non_source_files)})\.py$"}]
+			rev="v0.5.1",
+			hooks=[{"id": "yapf-isort", "exclude": yapf_isort_excludes}],
+			)
+
+	dep_checker = Repo(
+			repo=make_github_url("domdfcoding", "dep_checker"),
+			rev="v0.3.1",
+			hooks=[{"id": "dep_checker", "args": [templates.globals["import_name"].replace(".", "/")]}]
 			)
 
 	pre_commit_file = PathPlus(repo_path / ".pre-commit-config.yaml")
 
-	dumper = yaml.YAML()
+	if not pre_commit_file.is_file():
+		pre_commit_file.touch()
+
+	dumper = ruamel.yaml.YAML()
 	dumper.indent(mapping=2, sequence=3, offset=1)
 
 	output = StringList([
@@ -266,7 +278,7 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 
 	indent_re = re.compile("^ {3}")
 
-	for hook in [
+	managed_hooks = [
 			pre_commit_hooks,
 			domdfcoding_hooks,
 			flake8_dunder_all,
@@ -274,11 +286,36 @@ def make_pre_commit(repo_path: pathlib.Path, templates: jinja2.Environment) -> L
 			pyupgrade,
 			lucas_c_hooks,
 			yapf_isort,
-			]:
+			dep_checker,
+			]
+	managed_hooks_urls = [str(hook.repo) for hook in managed_hooks]
+
+	custom_hooks_comment = "# Custom hooks can be added below this comment"
+
+	for hook in managed_hooks:
 		buf = StringIO()
 		dumper.dump(hook.to_dict(), buf)
 		output.append(indent_re.sub(" - ", indent(buf.getvalue(), "   ")))
 		output.blankline(ensure_single=True)
+	output.append(custom_hooks_comment)
+	output.blankline(ensure_single=True)
+
+	raw_yaml = pre_commit_file.read_text()
+
+	if custom_hooks_comment in raw_yaml:
+		custom_hooks_yaml = pre_commit_file.read_text().split(custom_hooks_comment)[1]
+
+		custom_hooks = [
+				Repo(**repo)
+				for repo in ruamel.yaml.safe_load(custom_hooks_yaml) or []
+				if repo["repo"] not in managed_hooks_urls
+				]
+
+		for hook in custom_hooks:
+			buf = StringIO()
+			dumper.dump(hook.to_dict(), buf)
+			output.append(indent_re.sub(" - ", indent(buf.getvalue(), "   ")))
+			output.blankline(ensure_single=True)
 
 	pre_commit_file.write_lines(output)
 
