@@ -73,7 +73,6 @@ class ToxConfig(IniConfigurator):
 			"testenv:docs",
 			"testenv:build",
 			"testenv:lint",
-			"testenv:yapf",
 			"testenv:mypy",
 			"testenv:pyup",
 			"testenv:coverage",
@@ -273,7 +272,8 @@ class ToxConfig(IniConfigurator):
 		self._ini["testenv:build"]["commands"] = indent_join([
 				'python -m pep517.build --source --binary "{toxinidir}"',
 				# python setup.py {posargs} sdist bdist_wheel
-				"twine check dist/*",
+				# "twine check dist/*",
+				"twine check dist/*.tar.gz dist/*.whl",  # source
 				"check-wheel-contents dist/",
 				])
 
@@ -282,6 +282,7 @@ class ToxConfig(IniConfigurator):
 		``[testenv:lint]``.
 		"""
 
+		# TODO: https://github.com/asottile/yesqa
 		self._ini["testenv:lint"]["basepython"] = "python{min_py_version}".format(**self._globals)
 		self._ini["testenv:lint"]["changedir"] = "{toxinidir}"
 		self._ini["testenv:lint"]["ignore_errors"] = True
@@ -292,7 +293,7 @@ class ToxConfig(IniConfigurator):
 				"flake8-2020 >= 1.6.0",
 				"flake8-builtins>=1.5.3",
 				"flake8-docstrings>=1.5.0",
-				"flake8-dunder-all>=0.0.4",
+				"flake8-dunder-all>=0.1.1",
 				"flake8-pyi>=20.10.0",
 				"flake8-pytest-style>=1.3.0",
 				"flake8-sphinx-links>=0.0.4",
@@ -308,26 +309,6 @@ class ToxConfig(IniConfigurator):
 		cmd = f"python3 -m flake8_rst_docstrings_sphinx {' '.join(self.get_source_files())} --allow-toolbox"
 		self._ini["testenv:lint"]["commands"] = cmd
 
-	def testenv_yapf(self):
-		"""
-		``[testenv:yapf]``.
-		"""
-
-		self._ini["testenv:yapf"]["basepython"] = "python3.7"
-		self._ini["testenv:yapf"]["changedir"] = "{toxinidir}"
-		self._ini["testenv:yapf"]["skip_install"] = True
-		self._ini["testenv:yapf"]["ignore_errors"] = True
-		self._ini["testenv:yapf"]["deps"] = "yapf"
-
-		yapf_commands = [f"yapf -i --recursive {' '.join(self.get_source_files())}"]
-		if self["yapf_exclude"]:
-			yapf_commands.append("--exclude")
-
-			for exclude in self["yapf_exclude"]:
-				yapf_commands.append(f'"{exclude}"')
-
-		self._ini["testenv:yapf"]["commands"] = ' '.join(yapf_commands)
-
 	def testenv_mypy(self):
 		"""
 		``[testenv:mypy]``.
@@ -629,7 +610,9 @@ class TestsRequirementsManager(RequirementsManager):
 
 	def compile_target_requirements(self) -> None:
 		if self._globals["pypi_name"] != "coverage_pyver_pragma":
-			self.target_requirements.add(Requirement("coverage_pyver_pragma>=0.0.6"))
+			self.target_requirements.add(Requirement("coverage-pyver-pragma>=0.0.6"))
+		if self._globals["pypi_name"] != "domdf_python_tools":
+			self.target_requirements.add(Requirement("domdf-python-tools[testing]>=1.5.0"))
 
 
 @management.register("test_requirements", ["enable_tests"])
